@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moo;
 use Music::Chord::Note;
@@ -83,6 +83,9 @@ sub cadence {
         $chord = _generate_chord( $args{scale}, $note, $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
     }
+    else {
+        die 'unknown cadence';
+    }
 
     return $cadence;
 }
@@ -103,6 +106,8 @@ sub _generate_chord {
         locrian    => 'i',
     );
 
+    die 'unknown scale' unless exists $diminished{$scale};
+
     # Figure out if the chord is diminished, minor, or major
     my $roman = $mtr->parse($note);
     my $type  = $roman =~ /^$diminished{$scale}$/ ? 'dim' : $roman =~ /^[a-z]/ ? 'm' : '';
@@ -131,7 +136,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -165,6 +170,8 @@ Patches welcome.
 
 The key or tonal center to use.  Default: C<C>
 
+Examples: C<G#>, C<Eb>
+
 =head2 scale
 
 The scale to use.  Default: C<major>
